@@ -3,17 +3,13 @@ import os
 
 import click
 
+from puddl.cli.base import root
 from puddl.conf import DBConfig, PuddlRC
 
 log = logging.getLogger(__name__)
 
 
-@click.group()
-def config():
-    pass
-
-
-@config.command()
+@root.command()
 @click.option('-f', '--force', is_flag=True)
 def init(force):
     if PuddlRC.exists():
@@ -24,13 +20,21 @@ def init(force):
     from dotenv import load_dotenv
 
     load_dotenv()
-    os.environ['PGAPPNAME'] = 'puddl config init'
+    os.environ['PGAPPNAME'] = 'puddl-config init'
 
     cfg = DBConfig()
     PuddlRC.write(dict(cfg))
 
 
-@config.command()
+@root.command()
 def show():
     for k, v in DBConfig().items():
         print(f'{k}={v}')
+
+
+def main():
+    root(auto_envvar_prefix='PUDDL')
+
+
+if __name__ == '__main__':
+    main()
