@@ -1,7 +1,8 @@
 from pathlib import Path
 
-from sqlalchemy import DateTime, func, Column, Integer, String, types, JSON, ForeignKey, \
+from sqlalchemy import DateTime, func, Column, Integer, String, types, ForeignKey, \
     UniqueConstraint
+from sqlalchemy.dialects.postgresql import JSON
 from sqlalchemy.orm import relationship
 
 from puddl.db.alchemy import Schema
