@@ -1,6 +1,6 @@
 from pathlib import Path
 
-from puddl.felix.git.libfs import find_dirs
+from puddl.felix.git.utils import find_dirs
 
 
 def test_find_dirs():
